@@ -26,7 +26,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.5.7"
+#define LIBGNUTLS_VERSION "0.5.8"
 
 #include <sys/types.h>
 #include <time.h>
@@ -58,7 +58,9 @@ typedef enum gnutls_digest_algorithm { GNUTLS_DIG_NULL=1, GNUTLS_DIG_MD5, GNUTLS
  */
 #define GNUTLS_MAX_ALGORITHM_NUM 8
 
-typedef enum gnutls_compression_method { GNUTLS_COMP_NULL=1, GNUTLS_COMP_ZLIB } gnutls_compression_method;
+typedef enum gnutls_compression_method { GNUTLS_COMP_NULL=1, 
+	GNUTLS_COMP_ZLIB, GNUTLS_COMP_LZO
+} gnutls_compression_method;
 
 typedef enum gnutls_connection_end { GNUTLS_SERVER=1, GNUTLS_CLIENT } gnutls_connection_end;
 
@@ -130,8 +132,6 @@ int gnutls_bye( gnutls_session session, gnutls_close_request how);
 int gnutls_handshake( gnutls_session session);
 int gnutls_rehandshake( gnutls_session session);
 
-int gnutls_handshake_get_direction(gnutls_session session);
-
 gnutls_alert_description gnutls_alert_get( gnutls_session session);
 int 		 gnutls_alert_send( gnutls_session, gnutls_alert_level, gnutls_alert_description);
 int 		 gnutls_alert_send_appropriate(  gnutls_session session, int err);
@@ -156,6 +156,7 @@ const char *gnutls_certificate_type_get_name( gnutls_certificate_type type);
 
 /* error functions */
 int gnutls_error_is_fatal( int error);
+int gnutls_error_to_alert( int err, int* level);
 
 void gnutls_perror( int error);
 const char* gnutls_strerror( int error);
@@ -173,6 +174,9 @@ ssize_t gnutls_record_recv( gnutls_session session, void *data, size_t sizeofdat
 #define gnutls_read gnutls_record_recv
 #define gnutls_write gnutls_record_send
 
+#define gnutls_handshake_get_direction gnutls_record_get_direction
+int gnutls_record_get_direction(gnutls_session session);
+
 size_t gnutls_record_get_max_size( gnutls_session session);
 ssize_t gnutls_record_set_max_size( gnutls_session session, size_t size);
 
@@ -598,18 +602,24 @@ int gnutls_pem_base64_decode_alloc( const char* header, const gnutls_datum *b64_
 #define GNUTLS_E_UNKNOWN_PK_ALGORITHM -80
 #define GNUTLS_E_OPENPGP_TRUSTDB_VERSION_UNSUPPORTED -81
 
+
 /* returned if libextra functionality was requested but
  * gnutls_global_init_extra() was not called.
  */
 #define GNUTLS_E_INIT_LIBEXTRA -82
-#define GNUTLS_E_LIBRARY_VERSION_MISMATCH -82
-#define GNUTLS_E_EXPORT_CIPHER_SUITE -83
+#define GNUTLS_E_LIBRARY_VERSION_MISMATCH -83
+
 
 /* returned if you need to generate temporary RSA 
  * parameters. These are needed for export cipher suites.
  */
 #define GNUTLS_E_NO_TEMPORARY_RSA_PARAMS -84
 
+#define GNUTLS_E_LZO_INIT_FAILED -85
+#define GNUTLS_E_NO_COMPRESSION_ALGORITHMS -86
+#define GNUTLS_E_NO_CIPHER_SUITES -87
+
+
 #define GNUTLS_E_UNIMPLEMENTED_FEATURE -250
 
 
