@@ -538,10 +538,9 @@ int _gnutls_server_select_suite(gnutls_session session, opaque *data, int datale
 	pk_algo = _gnutls_find_pk_algos_in_ciphersuites( data, datalen);
 
 	x = _gnutls_supported_ciphersuites(session, &ciphers);
-	if (x<=0) {
+	if (x < 0) { /* the case x==0 is handled within the function. */
 		gnutls_assert();
-		if (x<0) return x; 
-		else return GNUTLS_E_INVALID_REQUEST;
+		return x; 
 	}
 
 	/* Here we remove any ciphersuite that does not conform
@@ -635,13 +634,20 @@ int _gnutls_server_select_comp_method(gnutls_session session, opaque * data,
 	uint8 *ciphers;
 
 	x = _gnutls_supported_compression_methods(session, &ciphers);
+	if (x < 0) {
+		gnutls_assert();
+		return x;
+	}
+
 	memset( &session->internals.compression_method, '\0', sizeof(gnutls_compression_method));
 
 	for (j = 0; j < datalen; j++) {
 		for (i = 0; i < x; i++) {
 			if (ciphers[i] == data[j]) {
-				session->internals.compression_method =
+			        gnutls_compression_method method = 
 				    _gnutls_compression_get_id(ciphers[i]);
+
+				session->internals.compression_method = method;
 				gnutls_free(ciphers);
 
 				_gnutls_handshake_log("HSK: Selected Compression Method: %s\n",
@@ -717,10 +723,6 @@ int _gnutls_send_handshake(gnutls_session session, void *i_data,
 	uint32 datasize;
 	int pos = 0;
 
-	/* to know where the procedure was interrupted.
-	 */
-	session->internals.handshake_direction = 1; /* write */
-
 	if (i_data == NULL && i_datasize == 0) {
 		/* we are resuming a previously interrupted
 		 * send.
@@ -964,10 +966,6 @@ int _gnutls_recv_handshake(gnutls_session session, uint8 ** data,
 	opaque *dataptr = NULL;
 	HandshakeType recv_type;
 
-	/* to know where the procedure was interrupted.
-	 */
-	session->internals.handshake_direction = 0; /* read */
-
 	ret = _gnutls_recv_handshake_header(session, type, &recv_type);
 	if (ret < 0) {
 		if (ret == GNUTLS_E_UNEXPECTED_HANDSHAKE_PACKET
@@ -1071,12 +1069,17 @@ static int _gnutls_client_set_ciphersuite(gnutls_session session,
 {
 	uint8 z;
 	GNUTLS_CipherSuite *cipher_suites;
-	uint16 x;
+	int cipher_suite_num;
 	int i, err;
 
 	z = 1;
-	x = _gnutls_supported_ciphersuites(session, &cipher_suites);
-	for (i = 0; i < x; i++) {
+	cipher_suite_num = _gnutls_supported_ciphersuites(session, &cipher_suites);
+	if (cipher_suite_num < 0) {
+		gnutls_assert();
+		return cipher_suite_num;
+	}
+	
+	for (i = 0; i < cipher_suite_num; i++) {
 		if (memcmp(&cipher_suites[i], suite, 2) == 0) {
 			z = 0;
 		}
@@ -1139,21 +1142,26 @@ static int _gnutls_client_set_ciphersuite(gnutls_session session,
 static int _gnutls_client_set_comp_method(gnutls_session session,
 					  opaque comp_method)
 {
-	uint8 z;
+	int comp_methods_num;
 	uint8 *compression_methods;
 	int i;
 
-	z = _gnutls_supported_compression_methods(session,
+	comp_methods_num = _gnutls_supported_compression_methods(session,
 						  &compression_methods);
-	for (i = 0; i < z; i++) {
+	if ( comp_methods_num < 0) {
+		gnutls_assert();
+		return comp_methods_num;
+	}
+	
+	for (i = 0; i < comp_methods_num; i++) {
 		if (compression_methods[i] == comp_method) {
-			z = 0;
+			comp_methods_num = 0;
 		}
 	}
 
 	gnutls_free(compression_methods);
 
-	if (z != 0) {
+	if (comp_methods_num != 0) {
 		gnutls_assert();
 		return GNUTLS_E_UNKNOWN_COMPRESSION_ALGORITHM;
 	}
@@ -1315,10 +1323,9 @@ static int _gnutls_copy_ciphersuites(gnutls_session session,
 	int datalen, pos;
 
 	ret = _gnutls_supported_ciphersuites_sorted(session, &cipher_suites);
-	if (ret <= 0) {
+	if (ret < 0) {
 		gnutls_assert();
-		if (ret==0) return GNUTLS_E_INVALID_REQUEST;
-		else return ret;
+		return ret;
 	}
 
 	/* Here we remove any ciphersuite that does not conform
@@ -1767,22 +1774,6 @@ int gnutls_rehandshake(gnutls_session session)
 	return 0;
 }
 
-/**
-  * gnutls_handshake_get_direction - This function will return the session of the handshake protocol
-  * @session: is a a &gnutls_session structure.
-  *
-  * This function provides information about the handshake procedure, and
-  * is only useful if the gnutls_handshake() call was interrupted for some
-  * reason.
-  *
-  * Returns 0 if the function was interrupted while receiving data, and 
-  * 1 otherwise. 
-  *
-  **/
-int gnutls_handshake_get_direction(gnutls_session session) {
-	return session->internals.handshake_direction;
-}
-
 static int _gnutls_abort_handshake( gnutls_session session, int ret) {
 	if ( ((ret==GNUTLS_E_WARNING_ALERT_RECEIVED) && 
 		( gnutls_alert_get(session) == GNUTLS_A_NO_RENEGOTIATION))
@@ -2025,10 +2016,6 @@ static int _gnutls_send_handshake_final(gnutls_session session, int init)
 {
 	int ret = 0;
 
-	/* to know where the procedure was interrupted.
-	 */
-	session->internals.handshake_direction = 1; /* write */
-
 	/* Send the CHANGE CIPHER SPEC PACKET */
 
 	switch (STATE) {
@@ -2085,10 +2072,6 @@ static int _gnutls_recv_handshake_final(gnutls_session session, int init)
 	int ret = 0;
 	uint8 ch;
 
-	/* to know where the procedure was interrupted.
-	 */
-	session->internals.handshake_direction = 0; /* recv */
-
 	switch (STATE) {
 	case STATE0:
 	case STATE30:
