@@ -34,6 +34,7 @@
 #define HANDSHAKE_DEBUG // Prints some information on handshake 
 #define X509_DEBUG
 #define RECORD_DEBUG
+#define COMPRESSION_DEBUG
 #define DEBUG
 */
 
@@ -160,7 +161,9 @@ typedef enum gnutls_kx_algorithm { GNUTLS_KX_RSA=1, GNUTLS_KX_DHE_DSS,
 
 typedef enum gnutls_mac_algorithm { GNUTLS_MAC_NULL=1, GNUTLS_MAC_MD5, GNUTLS_MAC_SHA } gnutls_mac_algorithm;
 
-typedef enum gnutls_compression_method { GNUTLS_COMP_NULL=1, GNUTLS_COMP_ZLIB } gnutls_compression_method;
+typedef enum gnutls_compression_method { GNUTLS_COMP_NULL=1, GNUTLS_COMP_ZLIB,
+	GNUTLS_COMP_LZO
+} gnutls_compression_method;
 
 typedef enum gnutls_connection_end { GNUTLS_SERVER=1, GNUTLS_CLIENT } gnutls_connection_end;
 
@@ -550,10 +553,10 @@ typedef struct {
 						* which have 0xFF status.
 						*/
 	
-	/* Holds 0 if the handshake procedure was interrupted while
+	/* Holds 0 if the last called function was interrupted while
 	 * receiving, and non zero otherwise.
 	 */
-	int			handshake_direction;
+	int			direction;
 
 	/* If you add anything here, check _gnutls_handshake_internal_state_clear().
 	 */
